@@ -7,7 +7,7 @@ def cmd1(str):
     return os.popen(str).readlines()[0][:-1]
 
 def cmd2(str):
-    return string.split (cmd1(str))
+    return cmd1(str).split()
 
 setup(name = "cabocha-python",
 	version = cmd1("cabocha-config --version"),
